@@ -2,6 +2,7 @@
 
 namespace apexl\Io\modules\menu\entities;
 
+use apexl\entityCore\enums\Casts;
 use apexl\entityCore\traits\hasCasts;
 use apexl\Io\exceptions\RecordNotFoundException;
 use apexl\Io\includes\Entity;
@@ -12,6 +13,7 @@ use apexl\Io\modules\menu\includes\menuItem;
 use apexl\Io\modules\user\entities\userEntity;
 use apexl\Io\services\pathUtility;
 use apexl\Utils\Arrays\Merge;
+use app\module\newtonsTrailers\Enum\Permission\Common;
 use DateTimeImmutable;
 
 /**
@@ -48,10 +50,16 @@ class menuEntity extends Entity
         //set Defaults
         $this->name = 'navigation';
         $this->module = 'menu';
-        $this->permission = 'AllowAll';
+        $this->permission = Common::ALLOW_ALL;
         $this->active = 1;
     }
 
+    public function casts(): array
+    {
+        return [
+            'permission' => Casts::SERIALIZE,
+        ];
+    }
 
     /**
      * @throws RecordNotFoundException
